/*
 * This file is part of TechReborn, licensed under the MIT License (MIT).
 *
 * Copyright (c) 2017 TechReborn
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package techreborn.items.tools;

import net.minecraft.entity.item.EntityItem;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Blocks;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.EnumActionResult;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.SoundCategory;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import net.minecraftforge.server.permission.PermissionAPI;
import net.minecraftforge.server.permission.context.BlockPosContext;
import reborncore.common.IWrenchable;
import reborncore.common.util.RebornPermissions;
import techreborn.client.TechRebornCreativeTabMisc;
import techreborn.compat.CompatManager;
import techreborn.init.ModSounds;
import techreborn.items.ItemTR;
import techreborn.utils.IC2WrenchHelper;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

/**
 * Created by modmuss50 on 26/02/2016.
 */
public class ItemWrench extends ItemTR {

	public ItemWrench() {
		func_77637_a(TechRebornCreativeTabMisc.instance);
		func_77655_b("techreborn.wrench");
		func_77625_d(1);
	}

	@Override
	public EnumActionResult func_180614_a(EntityPlayer player, World world, BlockPos pos,
	                                  EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		if (!PermissionAPI.hasPermission(player.func_146103_bH(), RebornPermissions.WRENCH_BLOCK, new BlockPosContext(player, pos, world.func_180495_p(pos), facing))) {
			return EnumActionResult.PASS;
		}
		if (CompatManager.isIC2Loaded) {
			EnumActionResult result = IC2WrenchHelper.onItemUse(player.func_184586_b(hand), player, world, pos, hand, facing, hitX, hitY, hitZ);
			if (result == EnumActionResult.SUCCESS) {
				return result;
			}
		}
		if (world.func_175623_d(pos)) {
			return EnumActionResult.PASS;
		}
		TileEntity tile = world.func_175625_s(pos);
		if (tile == null) {
			return EnumActionResult.PASS;
		}
		if (!world.field_72995_K) {
			if (player.func_70093_af()) {
				List<ItemStack> items = new ArrayList<>();
				if (tile instanceof IWrenchable) {
					if (((IWrenchable) tile).wrenchCanRemove(player)) {
						ItemStack itemStack = ((IWrenchable) tile).getWrenchDrop(player);
						if (itemStack == null) {
							return EnumActionResult.FAIL;
						}
						items.add(itemStack);
					}
					if (!items.isEmpty()) {
						for (ItemStack itemStack : items) {

							Random rand = new Random();

							float dX = rand.nextFloat() * 0.8F + 0.1F;
							float dY = rand.nextFloat() * 0.8F + 0.1F;
							float dZ = rand.nextFloat() * 0.8F + 0.1F;

							EntityItem entityItem = new EntityItem(world, pos.func_177958_n() + dX, pos.func_177956_o() + dY,
								pos.func_177952_p() + dZ, itemStack.func_77946_l());

							if (itemStack.func_77942_o()) {
								entityItem.func_92059_d()
									.func_77982_d(itemStack.func_77978_p().func_74737_b());
							}

							float factor = 0.05F;
							entityItem.field_70159_w = rand.nextGaussian() * factor;
							entityItem.field_70181_x = rand.nextGaussian() * factor + 0.2F;
							entityItem.field_70179_y = rand.nextGaussian() * factor;
							if (!world.field_72995_K) {
								world.func_72838_d(entityItem);
							}
						}
					}
					world.func_184148_a(null, player.field_70165_t, player.field_70163_u,
						player.field_70161_v, ModSounds.BLOCK_DISMANTLE,
						SoundCategory.BLOCKS, 0.6F, 1F);
					if (!world.field_72995_K) {
						world.func_180501_a(pos, Blocks.field_150350_a.func_176223_P(), 2);
					}
					return EnumActionResult.SUCCESS;
				}
			}
			return EnumActionResult.PASS;
		} else {
			return EnumActionResult.PASS;
		}
	}

	@SideOnly(Side.CLIENT)
	public boolean func_77662_d() {
		return true;
	}
}
